@@ -6,7 +6,6 @@ use strict;
 use warnings;
 use Carp;
 require Exporter;
-use AutoLoader;
 our @ISA = qw(Exporter);
 our ($AUTOLOAD);
 
@@ -111,7 +110,7 @@ our @EXPORT_OK = qw(ERROR
 
 our @EXPORT = qw( ERROR );
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 # Preloaded methods go here.
 
@@ -245,11 +244,11 @@ __END__
 =encoding utf-8
 =head1 NAME
 
-Crypt::Crypt::Libmcrypt - Perl extension for libmcrypt,the mcrypt cryptographic library
+Crypt::Libmcrypt - Perl extension for libmcrypt,the mcrypt cryptographic library
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 SYNOPSIS
 
